You are viewing a plain text version of this content. The canonical link for it is here.
Posted to dev@lucene.apache.org by "Adrien Grand (JIRA)" <ji...@apache.org> on 2016/06/01 07:38:59 UTC
[jira] [Updated] (LUCENE-7309) Speed up Polygon2D construction
[ https://issues.apache.org/jira/browse/LUCENE-7309?page=com.atlassian.jira.plugin.system.issuetabpanels:all-tabpanel ]
Adrien Grand updated LUCENE-7309:
---------------------------------
Attachment: LUCENE-7309.patch
Here is a patch. IndexAndSearchOpenStreetMaps reports that the QPS goes from 2.58 (master) to 3.75 (patch) with the Cleveland polygon. Polygon2D construction alone went from ~260ms to ~160ms.
> Speed up Polygon2D construction
> -------------------------------
>
> Key: LUCENE-7309
> URL: https://issues.apache.org/jira/browse/LUCENE-7309
> Project: Lucene - Core
> Issue Type: Improvement
> Reporter: Adrien Grand
> Assignee: Adrien Grand
> Priority: Minor
> Attachments: LUCENE-7309.patch
>
>
> Polygon2D.create recursively sorts on each dimension to build a tree. However, it does not really need to sort the data, it just needs to compute the median and partition other values around it, which can be performed in O(n). If I am not mistaken, this would make Polygon2D.create run in O(n log(n)) rather than O(n log^2(n)) today.
--
This message was sent by Atlassian JIRA
(v6.3.4#6332)
---------------------------------------------------------------------
To unsubscribe, e-mail: dev-unsubscribe@lucene.apache.org
For additional commands, e-mail: dev-help@lucene.apache.org